// java wrapper for vtkChartHistogram2D object
//

package vtk;
import vtk.*;

public class vtkChartHistogram2D extends vtkChartXY
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Update_2();
  public void Update()
    { Update_2(); }

  private native void SetInputData_3(vtkImageData id0,int id1);
  public void SetInputData(vtkImageData id0,int id1)
    { SetInputData_3(id0,id1); }

  private native void SetTransferFunction_4(vtkScalarsToColors id0);
  public void SetTransferFunction(vtkScalarsToColors id0)
    { SetTransferFunction_4(id0); }

  private native long GetPlot_5(int id0);
  public vtkPlot GetPlot(int id0) {
    long temp = GetPlot_5(id0);

    if (temp == 0) return null;
    return (vtkPlot)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkChartHistogram2D() { super(); }

  public vtkChartHistogram2D(long id) { super(id); }
  public native long   VTKInit();

}
